@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: bower-json
 version: 0.8.0
-id: bower-json-0.8.0-e5efe5ff8a892e9a670a71c216790060
-key: bower_GB106WqnVmiJ69RhKx3v2q
+id: bower-json-0.8.0-8b42e3c4c7a9d2be40ca375bc2b9432c
+key: bower_67JB9kSMNHMGCNOMerdnpl
 license: MIT
 maintainer: harry@garrood.me
 homepage: https://github.com/hdgarrood/bower-json
@@ -22,10 +22,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/bower-json-0.8.0
-hs-libraries: HSbower-json-0.8.0-GB106WqnVmiJ69RhKx3v2q
+hs-libraries: HSbower-json-0.8.0-67JB9kSMNHMGCNOMerdnpl
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    aeson-better-errors-0.9.0.1-59403b30f4f27006e990088f17fb37ed
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    aeson-better-errors-0.9.0.1-05a0fea2071afcbbba2c9016d32723d2
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
